pub enum Error {
Io {
context: &'static str,
source: Error,
},
IoPath {
path: PathBuf,
context: &'static str,
source: Error,
},
NoLintScope {
path: PathBuf,
},
InvalidPathForLintScope {
path: PathBuf,
scope: LintScope,
expected: &'static str,
},
InvalidLintScope {
scope: LintScope,
function: &'static str,
expected: &'static str,
},
InvalidResources {
scope: LintScope,
lint_rule: String,
expected: LintScope,
},
Json {
error: Error,
context: String,
},
BuildInfo(Error),
PackageBuild(Error),
PackageInfo(Error),
SourceInfo(Error),
LintConfig(Error),
}Expand description
Errors that can occur when using alpm-lint.
Variants
Io
I/O error.
Fields
IoPath
I/O error with additional path info for more context.
Fields
NoLintScope
No lint scope could be automatically detected for a path.
InvalidPathForLintScope
The wrong type of path was provided for a lint scope.
Example
The LintScope::Package scope expects a directory. If a file is provided, this error
will be thrown.
Fields
InvalidLintScope
An incompatible lint scope has been provided to a function.
Fields
InvalidResources
An incompatible resource of specific scope is provided to a lint rule.
Fields
Json
JSON serialization error.
Fields
BuildInfo(Error)
alpm-buildinfo error.
PackageBuild(Error)
alpm-pkgbuild error.
PackageInfo(Error)
alpm-pkginfo error.
SourceInfo(Error)
alpm-srcinfo error.
LintConfig(Error)
alpm-lint-config error.